// Macro for Simcenter STAR-CCM+ 17.02.008 to update fairing geometry using csv point files (and TE/LE refinement zones) -> Run simulation -> Export monitors
// Required section shape files: upper portion of fairing (topFAIR.csv), lower portion of fairing (botFAIR.csv), top fairing leading edge refinement zone (topLEcircle.csv), top fairing trailing edge refinement zone (topTEcircle.csv), bottom fairing leading edge refinement zone (botLEcircle.csv), and bottom fairing trailing edge refinement zone (botTEcircle.csv)
// Requires same naming convention for: 3D CAD model (Fairing), sketches, and splines 

package macro;

import java.util.*;

import star.common.*;
import star.base.neo.*;
import star.base.report.*;
import star.vis.*;
import star.cadmodeler.*;
import star.meshing.*;

public class IterateFairing extends StarMacro {

  public void execute() {
    execute0();
  }

  private void execute0() {

    Simulation simulation_0 = 
      getActiveSimulation();


// Update geometry and remesh - using topFAIR.csv, botFAIR.csv, topLEcircle.csv, topTEcircle.csv, botLEcircle.csv, botTEcircle.csv

    Scene scene_0 = 
      simulation_0.getSceneManager().createScene("3D-CAD View");

    scene_0.initializeAndWait();

    CadModel cadModel_0 = 
      ((CadModel) simulation_0.get(SolidModelManager.class).getObject("Fairing"));

    simulation_0.get(SolidModelManager.class).editCadModel(cadModel_0, scene_0);

    Sketch3D sketch3D_0 = 
      ((Sketch3D) cadModel_0.getFeature("Sketch3D 1"));

    sketch3D_0.setAutoPreview(true);

    cadModel_0.allowMakingPartDirty(false);

    cadModel_0.getFeatureManager().updateModelForEditingFeature(sketch3D_0);

    cadModel_0.getFeatureManager().startSketch3DEdit(sketch3D_0);

    Units units_0 = 
      simulation_0.getUnitsManager().getPreferredUnits(Dimensions.Builder().length(1).build());

    sketch3D_0.setAutoPreview(true);

    cadModel_0.getFeatureManager().cancelSketch3DEdit(sketch3D_0);

    cadModel_0.allowMakingPartDirty(true);

    cadModel_0.getFeatureManager().updateModelAfterFeatureEditCancelled(sketch3D_0, null);

    sketch3D_0.setAutoPreview(true);

    cadModel_0.allowMakingPartDirty(false);

    cadModel_0.getFeatureManager().updateModelForEditingFeature(sketch3D_0);

    cadModel_0.getFeatureManager().startSketch3DEdit(sketch3D_0);


    SplineSketchPrimitive3D splineSketchPrimitive3D_0 = 
      ((SplineSketchPrimitive3D) sketch3D_0.getSketchPrimitive3D("Spline 1"));

    sketch3D_0.replaceSketchPrimitive3d(splineSketchPrimitive3D_0, resolvePath("./botFAIR.csv"));

    sketch3D_0.setIsBodyGroupCreation(false);

    cadModel_0.getFeatureManager().markDependentNotUptodate(sketch3D_0);

    sketch3D_0.markFeatureForEdit();

    cadModel_0.allowMakingPartDirty(true);

    cadModel_0.getFeatureManager().stopSketch3DEdit(sketch3D_0, false);

    cadModel_0.getFeatureManager().markDependentNotUptodate(sketch3D_0);

    cadModel_0.getFeatureManager().updateModelAfterFeatureEdited(sketch3D_0, null);

    Sketch3D sketch3D_1 = 
      ((Sketch3D) cadModel_0.getFeature("Sketch3D 2"));

    sketch3D_1.setAutoPreview(true);

    cadModel_0.allowMakingPartDirty(false);

    cadModel_0.getFeatureManager().updateModelForEditingFeature(sketch3D_1);

    cadModel_0.getFeatureManager().startSketch3DEdit(sketch3D_1);

    SplineSketchPrimitive3D splineSketchPrimitive3D_1 = 
      ((SplineSketchPrimitive3D) sketch3D_1.getSketchPrimitive3D("Spline 1"));

    sketch3D_1.replaceSketchPrimitive3d(splineSketchPrimitive3D_1, resolvePath("./topFAIR.csv"));

    sketch3D_1.setIsBodyGroupCreation(false);

    cadModel_0.getFeatureManager().markDependentNotUptodate(sketch3D_1);

    sketch3D_1.markFeatureForEdit();

    cadModel_0.allowMakingPartDirty(true);

    cadModel_0.getFeatureManager().stopSketch3DEdit(sketch3D_1, false);

    cadModel_0.getFeatureManager().markDependentNotUptodate(sketch3D_1);

    cadModel_0.getFeatureManager().updateModelAfterFeatureEdited(sketch3D_1, null);

    cadModel_0.update();

    simulation_0.get(SolidModelManager.class).endEditCadModel(cadModel_0);

    simulation_0.getSceneManager().deleteScenes(new NeoObjectVector(new Object[] {scene_0}));

    Scene scene_1 = 
      simulation_0.getSceneManager().createScene("3D-CAD View");

    scene_1.initializeAndWait();

    CadModel cadModel_1 = 
      ((CadModel) simulation_0.get(SolidModelManager.class).getObject("LE_TE"));

    simulation_0.get(SolidModelManager.class).editCadModel(cadModel_1, scene_1);

    Sketch3D sketch3D_2 = 
      ((Sketch3D) cadModel_1.getFeature("Sketch3D 1"));

    sketch3D_2.setAutoPreview(true);

    cadModel_1.allowMakingPartDirty(false);

    cadModel_1.getFeatureManager().updateModelForEditingFeature(sketch3D_2);

    cadModel_1.getFeatureManager().startSketch3DEdit(sketch3D_2);

    SplineSketchPrimitive3D splineSketchPrimitive3D_2 = 
      ((SplineSketchPrimitive3D) sketch3D_2.getSketchPrimitive3D("Spline 1"));

    sketch3D_2.replaceSketchPrimitive3d(splineSketchPrimitive3D_2, resolvePath("./botLEcircle.csv"));

    sketch3D_2.setIsBodyGroupCreation(false);

    cadModel_1.getFeatureManager().markDependentNotUptodate(sketch3D_2);

    sketch3D_2.markFeatureForEdit();

    cadModel_1.allowMakingPartDirty(true);

    cadModel_1.getFeatureManager().stopSketch3DEdit(sketch3D_2, false);

    cadModel_1.getFeatureManager().markDependentNotUptodate(sketch3D_2);

    cadModel_1.getFeatureManager().updateModelAfterFeatureEdited(sketch3D_2, null);

    Sketch3D sketch3D_3 = 
      ((Sketch3D) cadModel_1.getFeature("Sketch3D 2"));

    sketch3D_3.setAutoPreview(true);

    cadModel_1.allowMakingPartDirty(false);

    cadModel_1.getFeatureManager().updateModelForEditingFeature(sketch3D_3);

    cadModel_1.getFeatureManager().startSketch3DEdit(sketch3D_3);

    SplineSketchPrimitive3D splineSketchPrimitive3D_3 = 
      ((SplineSketchPrimitive3D) sketch3D_3.getSketchPrimitive3D("Spline 1"));

    sketch3D_3.replaceSketchPrimitive3d(splineSketchPrimitive3D_3, resolvePath("./botTEcircle.csv"));

    sketch3D_3.setIsBodyGroupCreation(false);

    cadModel_1.getFeatureManager().markDependentNotUptodate(sketch3D_3);

    sketch3D_3.markFeatureForEdit();

    cadModel_1.allowMakingPartDirty(true);

    cadModel_1.getFeatureManager().stopSketch3DEdit(sketch3D_3, false);

    cadModel_1.getFeatureManager().markDependentNotUptodate(sketch3D_3);

    cadModel_1.getFeatureManager().updateModelAfterFeatureEdited(sketch3D_3, null);

    Sketch3D sketch3D_4 = 
      ((Sketch3D) cadModel_1.getFeature("Sketch3D 3"));

    sketch3D_4.setAutoPreview(true);

    cadModel_1.allowMakingPartDirty(false);

    cadModel_1.getFeatureManager().updateModelForEditingFeature(sketch3D_4);

    cadModel_1.getFeatureManager().startSketch3DEdit(sketch3D_4);

    SplineSketchPrimitive3D splineSketchPrimitive3D_4 = 
      ((SplineSketchPrimitive3D) sketch3D_4.getSketchPrimitive3D("Spline 1"));

    sketch3D_4.replaceSketchPrimitive3d(splineSketchPrimitive3D_4, resolvePath("./topLEcircle.csv"));

    sketch3D_4.setIsBodyGroupCreation(false);

    cadModel_1.getFeatureManager().markDependentNotUptodate(sketch3D_4);

    sketch3D_4.markFeatureForEdit();

    cadModel_1.allowMakingPartDirty(true);

    cadModel_1.getFeatureManager().stopSketch3DEdit(sketch3D_4, false);

    cadModel_1.getFeatureManager().markDependentNotUptodate(sketch3D_4);

    cadModel_1.getFeatureManager().updateModelAfterFeatureEdited(sketch3D_4, null);

    Sketch3D sketch3D_5 = 
      ((Sketch3D) cadModel_1.getFeature("Sketch3D 4"));

    sketch3D_5.setAutoPreview(true);

    cadModel_1.allowMakingPartDirty(false);

    cadModel_1.getFeatureManager().updateModelForEditingFeature(sketch3D_5);

    cadModel_1.getFeatureManager().startSketch3DEdit(sketch3D_5);

    SplineSketchPrimitive3D splineSketchPrimitive3D_5 = 
      ((SplineSketchPrimitive3D) sketch3D_5.getSketchPrimitive3D("Spline 1"));

    sketch3D_5.replaceSketchPrimitive3d(splineSketchPrimitive3D_5, resolvePath("./topTEcircle.csv"));

    sketch3D_5.setIsBodyGroupCreation(false);

    cadModel_1.getFeatureManager().markDependentNotUptodate(sketch3D_5);

    sketch3D_5.markFeatureForEdit();

    cadModel_1.allowMakingPartDirty(true);

    cadModel_1.getFeatureManager().stopSketch3DEdit(sketch3D_5, false);

    cadModel_1.getFeatureManager().markDependentNotUptodate(sketch3D_5);

    cadModel_1.getFeatureManager().updateModelAfterFeatureEdited(sketch3D_5, null);

    cadModel_1.update();

    simulation_0.get(SolidModelManager.class).endEditCadModel(cadModel_1);

    simulation_0.getSceneManager().deleteScenes(new NeoObjectVector(new Object[] {scene_1}));

    SolidModelPart solidModelPart_0 = 
      ((SolidModelPart) simulation_0.get(SimulationPartManager.class).getPart("topFAIR"));

    simulation_0.get(SimulationPartManager.class).updateParts(new NeoObjectVector(new Object[] {solidModelPart_0}));

    SolidModelPart solidModelPart_1 = 
      ((SolidModelPart) simulation_0.get(SimulationPartManager.class).getPart("topLEcircle"));

    simulation_0.get(SimulationPartManager.class).updateParts(new NeoObjectVector(new Object[] {solidModelPart_1}));

    simulation_0.get(MeshOperationManager.class).executeAll();


// Run simulation

    simulation_0.getSimulationIterator().run();


// Export monitors

    ReportMonitor reportMonitor_3 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("Cp Monitor"));

    ReportMonitor reportMonitor_4 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FX_botFAIR Monitor"));

    ReportMonitor reportMonitor_5 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FX_Foil1 Monitor"));

    ReportMonitor reportMonitor_6 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FX_Foil2 Monitor"));

    ReportMonitor reportMonitor_7 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FX_Foil3 Monitor"));

    ReportMonitor reportMonitor_8 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FX_topFAIR Monitor"));

    ReportMonitor reportMonitor_9 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FY_botFAIR Monitor"));

    ReportMonitor reportMonitor_0 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FY_Foil1 Monitor"));

    ReportMonitor reportMonitor_1 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FY_Foil2 Monitor"));

    ReportMonitor reportMonitor_2 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FY_Foil3 Monitor"));

    ReportMonitor reportMonitor_10 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("FY_topFAIR Monitor"));

    ReportMonitor reportMonitor_11 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("M_Foil1 Monitor"));

    ReportMonitor reportMonitor_12 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("M_Foil2 Monitor"));

    ReportMonitor reportMonitor_13 = 
      ((ReportMonitor) simulation_0.getMonitorManager().getMonitor("M_Foil3 Monitor"));

    simulation_0.getMonitorManager().export("./Export.csv", ",", new NeoObjectVector(new Object[] {reportMonitor_3, reportMonitor_4, reportMonitor_5, reportMonitor_6, reportMonitor_7, reportMonitor_8, reportMonitor_9, reportMonitor_0, reportMonitor_1, reportMonitor_2, reportMonitor_10, reportMonitor_11, reportMonitor_12, reportMonitor_13}));


  }
}
